Calculate the Hopkins' statistic
Calculate the Hopkins' statistic of given data.
Note:"Package clustertend is deprecated. Use package hopkins instead.
Sample data must be preprocessed into dataframe or matrix form before given as the value of parameter "data".